/*
 * Task.java
 */

package com.builder.uk.todotasks;

import java.io.Serializable;
import java.util.Date;

/**
 * A simple bean for holding Task information
 * @author Dj Walker-Morgan
 */
public class Task implements Serializable {

    static final long serialVersionUID = 4331222314356659203L;
    
    private Long taskId;
    private String name="";
    private String notes="";
    private Date completedDate=null;
    private Priority priority=Priority.NONE;
    private int donePercent=0;
    private Date dueDate=null;
    
    /**
     * Creates a new instance of Task
     */
    public Task() {
    }

    /**
     * Gets the Task name
     * @return the Task name
     */
    public String getName() {
        return name;
    }

    /**
     * Sets the Task name
     * @param name the new Task name
     */
    public void setName(String name) {
        this.name = name;
    }

    /**
     * Gets the Task notes
     * @return the Task notes
     */
    public String getNotes() {
        return notes;
    }

    /**
     * Sets the Task note text
     * @param notes the new note text
     */
    public void setNotes(String notes) {
        this.notes = notes;
    }

    /**
     * Gets the completed date
     * @return the completed date
     */
    public Date getCompletedDate() {
        return completedDate;
    }

    /**
     * Sets the completed date
     * @param completedDate the new completed date
     */
    public void setCompletedDate(Date completedDate) {
        this.completedDate = completedDate;
    }

    /**
     * Gets the Task priority
     * @return the priority
     */
    public Priority getPriority() {
        return priority;
    }

    /**
     * Set the Task priority
     * @param priority the new priority value
     */
    public void setPriority(Priority priority) {
        this.priority = priority;
    }

    /**
     * Gets the percentage done value
     * @return the done value
     */
    public int getDonePercent() {
        return donePercent;
    }

    /**
     * Sets the percentage done value
     * @param donePercent the new done value
     */
    public void setDonePercent(int donePercent) {
        this.donePercent = donePercent;
    }

    /**
     * Gets the Task id value
     * @return the Task id value
     */
    public Long getTaskId() {
        return taskId;
    }

    /**
     * Set the Task id value
     * @param id the new Task id
     */
    public void setTaskId(Long id) {
        this.taskId = id;
    }

    /**
     * get the due date for the task
     * @return Date due or null for no due date
     */
    public Date getDueDate() {
        return dueDate;
    }

    /**
     * Sets due date
     * @param dueDate Date task is due or null if no due date
     */
    public void setDueDate(Date dueDate) {
        this.dueDate = dueDate;
    }
    
}
